
package de.codedo.conflicteditor;

import java.net.MalformedURLException;
import java.net.URL;

public class CouchDb
{
    private String _baseUrl;

    public CouchDb(String baseUrl) throws MalformedURLException
    {
        super();
        check(baseUrl);
        initBaseUrl(baseUrl);
    }

    private void check(String baseUrl) throws MalformedURLException
    {
        if (baseUrl == null)
        {
            throw new IllegalArgumentException("base url may not be null");
        }
        if (baseUrl.length() == 0)
        {
            throw new MalformedURLException("base url may not be empty");
        }
    }

    private void initBaseUrl(String baseUrl)
    {
        if (baseUrl.endsWith("/") == false)
        {
            baseUrl += "/";
        }
        _baseUrl = baseUrl;
    }

    public URL urlByAddingPath(String path) throws MalformedURLException
    {
        String extendedPath = appendPathToBaseUrl(path);
        return new URL(extendedPath);
    }

    public URL urlForDocumentAndRevision(String id, String revision) throws MalformedURLException
    {
        String path = String.format("%s?rev=%s", appendPathToBaseUrl(id), revision);
        return new URL(path);
    }

    private String appendPathToBaseUrl(String path)
    {
        if (path.startsWith("/"))
        {
            path = path.substring(1);
        }
        return _baseUrl + path;
    }
}
