
package de.codedo.conflicteditor;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.codehaus.jackson.JsonNode;

public class DocumentMatcher
{
    // @formatter:off
    private static final Collection<String> IGNORED_FIELD_NAMES = Arrays.asList(
        "_id", "_rev","_conflicts"
    );
    // @formatter:on

    private JsonNode _original;
    private JsonNode _other;

    public DocumentMatcher(JsonNode original, JsonNode other)
    {
        super();
        _original = original;
        _other = other;
    }

    public void compare()
    {
        Set<String> originalFieldNames = getFieldNames(_original);
        for (String name : originalFieldNames)
        {
            Object originalValue = _original.findValue(name).getValueAsText();
            Object otherValue = _other.findValue(name).getValueAsText();
            if (originalValue.equals(otherValue) == false)
            {
                System.out.printf("%s : \"%s\" - \"%s\"\n", name, originalValue, otherValue);
            }
        }
    }

    private Set<String> getFieldNames(JsonNode node)
    {
        Set<String> fieldNames = new HashSet<String>();
        Iterator<String> fieldNameIter = node.getFieldNames();
        while (fieldNameIter.hasNext())
        {
            String name = fieldNameIter.next();
            if (IGNORED_FIELD_NAMES.contains(name) == false)
            {
                fieldNames.add(name);
            }
        }
        return fieldNames;
    }
}
