
package de.codedo.conflicteditor;

import static org.hamcrest.core.IsEqual.equalTo;
import static org.junit.Assert.assertThat;

import org.codehaus.jackson.JsonNode;
import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.node.ArrayNode;
import org.codehaus.jackson.node.ObjectNode;
import org.junit.Test;

public class ConflictTestCase extends Object
{
    private static final String BASE_REVISION = "24-223d00d8f77d78a2911cbb265f5025eb";
    private static final String CONFLICT_REVISION = "16-7f27b886bf38e4f9e543bee0ddf85758";
    private static final String ID = "54620eb9a46d495eac294a3bd52f7b00";

    @Test
    public void idFromConflict() throws Exception
    {
        JsonNode node = createNodeWithConflictRevisions(CONFLICT_REVISION);
        Conflict conflict = new Conflict(node);
        assertThat(conflict.getId(), equalTo(ID));
    }

    @Test
    public void baseRevisionFromConflict()
    {
        JsonNode node = createNodeWithConflictRevisions(CONFLICT_REVISION);
        Conflict conflict = new Conflict(node);
        assertThat(conflict.getRevision(), equalTo(BASE_REVISION));
    }

    @Test
    public void conflictingRevisionFromConflict()
    {
        JsonNode node = createNodeWithConflictRevisions(CONFLICT_REVISION);
        Conflict conflict = new Conflict(node);
        assertThat(conflict.getConflictRevision(), equalTo(CONFLICT_REVISION));
    }

    private ObjectNode createNodeWithConflictRevisions(String... revisions)
    {
        ObjectNode node = createBaseNode();
        ObjectNode keyNode = (ObjectNode)node.findValue("key");

        ArrayNode conflicts = node.arrayNode();
        for (String revision : revisions)
        {
            conflicts.add(revision);
        }
        keyNode.put("_conflicts", conflicts);
        return node;
    }

    private ObjectNode createBaseNode()
    {
        ObjectMapper mapper = new ObjectMapper();
        ObjectNode node = mapper.createObjectNode();
        node.put("id", ID);

        ObjectNode keyNode = node.objectNode();
        keyNode.put("_id", ID);
        keyNode.put("_rev", BASE_REVISION);
        node.put("key", keyNode);

        ArrayNode valueNode = node.arrayNode();
        valueNode.add(CONFLICT_REVISION);
        node.put("value", valueNode);

        return node;
    }
}
