
package de.codedo.conflicteditor;

import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.Reader;
import java.net.URL;

import org.codehaus.jackson.JsonNode;
import org.codehaus.jackson.map.ObjectMapper;

public class Playground extends Object
{
    private static final String BASE_URL = "http://localhost:5984/conflicts";

    public static void main(String[] args) throws Exception
    {
        CouchDb database = new CouchDb(BASE_URL);

        ConflictsView conflictsView = new ConflictsView(database);
        JsonNode conflicts = conflictsView.getConflicts();

        int size = conflicts.size();
        for (int i = 0; i < size; i++)
        {
            Conflict conflict = new Conflict(conflicts.get(i));
            JsonNode currentDocument = conflict.getCurrentDocument();
            System.out.println(currentDocument.findValue("rss_url").getTextValue());
            // System.out.println("current:");
            // prettyPrint(currentDocument);

            URL documentUrl = database.urlForDocumentAndRevision(conflict.getId(),
                conflict.getConflictRevision());
            System.out.printf("curl -X DELETE \"%s\"\n", documentUrl);
            Reader reader = new UrlConnectionHttpAccess(documentUrl).get();

            JsonNode conflictDocument = new ObjectMapper().readTree(reader);
            // System.out.println("\nconflict:");
            // prettyPrint(conflictDocument);

            compare(currentDocument, conflictDocument);
            System.out.println("\n");
        }
    }

    private static void compare(JsonNode currentDocument, JsonNode conflictDocument)
    {
        new DocumentMatcher(currentDocument, conflictDocument).compare();
    }

    private static void prettyPrint(JsonNode node) throws IOException
    {
        PrintStream out = new IgnoreClosePrintStream(System.out);
        new ObjectMapper().defaultPrettyPrintingWriter().writeValue(out, node);
    }

    private static class IgnoreClosePrintStream extends PrintStream
    {
        public IgnoreClosePrintStream(OutputStream outputStream)
        {
            super(outputStream);
        }

        @Override
        public void close()
        {
            // do not close
        }
    }
}
